# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCompetitionOrganiserInfo(BaseModel):
    get_competition_organiser_info: Optional[
        "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfo"
    ] = Field(alias="getCompetitionOrganiserInfo")


class GetCompetitionOrganiserInfoGetCompetitionOrganiserInfo(BaseModel):
    units: Optional[
        List[Optional["GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoUnits"]]
    ]
    website_url: Optional[str] = Field(alias="websiteUrl")
    results_page_url: Optional[str] = Field(alias="resultsPageUrl")
    live_streaming_url: Optional[str] = Field(alias="liveStreamingUrl")
    contact_persons_general_matters: Optional[
        List[
            Optional[
                "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralMatters"
            ]
        ]
    ] = Field(alias="contactPersonsGeneralMatters")
    contact_persons_general_results: Optional[
        List[
            Optional[
                "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralResults"
            ]
        ]
    ] = Field(alias="contactPersonsGeneralResults")


class GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoUnits(BaseModel):
    events: Optional[List[Optional[str]]]
    gender: Optional[str]


class GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralMatters(
    BaseModel
):
    name: Optional[str]
    email: Optional[str]
    phone_number: Optional[str] = Field(alias="phoneNumber")


class GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralResults(
    BaseModel
):
    name: Optional[str]
    email: Optional[str]
    phone_number: Optional[str] = Field(alias="phoneNumber")


GetCompetitionOrganiserInfo.update_forward_refs()
GetCompetitionOrganiserInfoGetCompetitionOrganiserInfo.update_forward_refs()
GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoUnits.update_forward_refs()
GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralMatters.update_forward_refs()
GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralResults.update_forward_refs()
