# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetWawEventCountryList(BaseModel):
    get_waw_event_country_list: Optional[
        List[Optional["GetWawEventCountryListGetWawEventCountryList"]]
    ] = Field(alias="getWawEventCountryList")


class GetWawEventCountryListGetWawEventCountryList(BaseModel):
    letter: Optional[str]
    countries: Optional[
        List[Optional["GetWawEventCountryListGetWawEventCountryListCountries"]]
    ]


class GetWawEventCountryListGetWawEventCountryListCountries(BaseModel):
    name: Optional[str]
    code: Optional[str]
    slug: Optional[str]


GetWawEventCountryList.update_forward_refs()
GetWawEventCountryListGetWawEventCountryList.update_forward_refs()
GetWawEventCountryListGetWawEventCountryListCountries.update_forward_refs()
