# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetAllGoldTourEvents(BaseModel):
    get_all_gold_tour_events: Optional[
        "GetAllGoldTourEventsGetAllGoldTourEvents"
    ] = Field(alias="getAllGoldTourEvents")


class GetAllGoldTourEventsGetAllGoldTourEvents(BaseModel):
    events: Optional[List[Optional["GetAllGoldTourEventsGetAllGoldTourEventsEvents"]]]


class GetAllGoldTourEventsGetAllGoldTourEventsEvents(BaseModel):
    nameof_event: Optional[str] = Field(alias="NameofEvent")
    nameof_location: Optional[str] = Field(alias="NameofLocation")
    youtube_video_id: Optional[str] = Field(alias="YoutubeVideoId")
    event_date: Optional[str] = Field(alias="EventDate")


GetAllGoldTourEvents.update_forward_refs()
GetAllGoldTourEventsGetAllGoldTourEvents.update_forward_refs()
GetAllGoldTourEventsGetAllGoldTourEventsEvents.update_forward_refs()
