# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/schema.graphql

from enum import Enum


class AirQualityDeviceFilter(str, Enum):
    all = "all"
    linked = "linked"
    unlinked = "unlinked"


class CarouselTypeEnum(str, Enum):
    Home = "Home"
    News = "News"
    SingleNews = "SingleNews"
    SingleFeature = "SingleFeature"
    AthleteHero = "AthleteHero"
    BeActiveHero = "BeActiveHero"
    PersonalBest = "PersonalBest"
    Video = "Video"
    UpcomingEvent = "UpcomingEvent"
    EventReport = "EventReport"


class eventPhaseOrderByEnum(str, Enum):
    PhaseDateAndTime = "PhaseDateAndTime"
    PhaseOrder = "PhaseOrder"


class GenderType(str, Enum):
    male = "male"
    female = "female"


class medalsOrderByEnum(str, Enum):
    GOLD = "GOLD"
    TOTAL = "TOTAL"


class MetaDataTypes(str, Enum):
    countryCodes = "countryCodes"
    disciplineCodes = "disciplineCodes"


class OrderByEnum(str, Enum):
    LiveFrom = "LiveFrom"
    EndDate = "EndDate"
    StartDate = "StartDate"


class OrderByLiveBlogPostEnum(str, Enum):
    CreatedDate = "CreatedDate"
    PublishedDate = "PublishedDate"


class OrderByNewArticleEnum(str, Enum):
    PublishedDate = "PublishedDate"
    CreatedDate = "CreatedDate"
    Title = "Title"


class OrderDirectionEnum(str, Enum):
    Ascending = "Ascending"
    Descending = "Descending"


class PlacingTableOrderBy(str, Enum):
    RANK = "RANK"
    TABLE_ORDER = "TABLE_ORDER"


class RelatedCompetitionEnum(str, Enum):
    FeaturedResults = "FeaturedResults"


class TeamStandingOrderBy(str, Enum):
    EVENTTEAMSTANDINGORDER = "EVENTTEAMSTANDINGORDER"
