# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class AirQualityDeviceElementReads(BaseModel):
    air_quality_device_element_reads: Optional[
        List[Optional["AirQualityDeviceElementReadsAirQualityDeviceElementReads"]]
    ] = Field(alias="airQualityDeviceElementReads")


class AirQualityDeviceElementReadsAirQualityDeviceElementReads(BaseModel):
    value: Optional[str]
    validation: Optional[str]
    reason: Optional[str]
    ts: Optional[Any]


AirQualityDeviceElementReads.update_forward_refs()
AirQualityDeviceElementReadsAirQualityDeviceElementReads.update_forward_refs()
