# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetCompetitor(BaseModel):
    get_competitor: Optional["GetCompetitorGetCompetitor"] = Field(
        alias="getCompetitor"
    )


class GetCompetitorGetCompetitor(BaseModel):
    competitor_id: Optional[int] = Field(alias="competitorId")
    old_competitor_id: Optional[int] = Field(alias="oldCompetitorId")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    birth_date: Optional[str] = Field(alias="birthDate")
    birth_place: Optional[str] = Field(alias="birthPlace")
    birth_country_code: Optional[str] = Field(alias="birthCountryCode")
    birth_place_country_name: Optional[str] = Field(alias="birthPlaceCountryName")
    team_name: Optional[str] = Field(alias="teamName")
    country_name: Optional[str] = Field(alias="countryName")
    country_code: Optional[str] = Field(alias="countryCode")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    full_bio: Optional[str] = Field(alias="fullBio")
    butlers_bio: Optional[str] = Field(alias="butlersBio")
    event_store_id: Optional[str] = Field(alias="eventStoreId")


GetCompetitor.update_forward_refs()
GetCompetitorGetCompetitor.update_forward_refs()
