# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetNewsTicker(BaseModel):
    get_news_ticker: Optional["GetNewsTickerGetNewsTicker"] = Field(
        alias="getNewsTicker"
    )


class GetNewsTickerGetNewsTicker(BaseModel):
    content: Optional[str]


GetNewsTicker.update_forward_refs()
GetNewsTickerGetNewsTicker.update_forward_refs()
