# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetSingleCompetitorHonourSummary(BaseModel):
    get_single_competitor_honour_summary: Optional[
        List[
            Optional["GetSingleCompetitorHonourSummaryGetSingleCompetitorHonourSummary"]
        ]
    ] = Field(alias="getSingleCompetitorHonourSummary")


class GetSingleCompetitorHonourSummaryGetSingleCompetitorHonourSummary(BaseModel):
    count: Optional[int]
    honour: Optional[str]


GetSingleCompetitorHonourSummary.update_forward_refs()
GetSingleCompetitorHonourSummaryGetSingleCompetitorHonourSummary.update_forward_refs()
