# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetVideosTotalNumber(BaseModel):
    get_videos_total_number: Optional[
        "GetVideosTotalNumberGetVideosTotalNumber"
    ] = Field(alias="getVideosTotalNumber")


class GetVideosTotalNumberGetVideosTotalNumber(BaseModel):
    total: Optional[str]


GetVideosTotalNumber.update_forward_refs()
GetVideosTotalNumberGetVideosTotalNumber.update_forward_refs()
