# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetArticleLocations(BaseModel):
    get_article_locations: Optional[
        List[Optional["GetArticleLocationsGetArticleLocations"]]
    ] = Field(alias="getArticleLocations")


class GetArticleLocationsGetArticleLocations(BaseModel):
    id: Optional[str]
    name: Optional[str]
    latitude: Optional[float]
    longitude: Optional[float]


GetArticleLocations.update_forward_refs()
GetArticleLocationsGetArticleLocations.update_forward_refs()
