# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCompetitorsLegacyPrimaryMedia(BaseModel):
    get_competitors_legacy_primary_media: Optional[
        List[
            Optional["GetCompetitorsLegacyPrimaryMediaGetCompetitorsLegacyPrimaryMedia"]
        ]
    ] = Field(alias="getCompetitorsLegacyPrimaryMedia")


class GetCompetitorsLegacyPrimaryMediaGetCompetitorsLegacyPrimaryMedia(BaseModel):
    id: Optional[str]
    competitor_id: Optional[int] = Field(alias="competitorId")
    file_name: Optional[str] = Field(alias="fileName")


GetCompetitorsLegacyPrimaryMedia.update_forward_refs()
GetCompetitorsLegacyPrimaryMediaGetCompetitorsLegacyPrimaryMedia.update_forward_refs()
