# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetCompetitorAAId(BaseModel):
    get_competitor_a_a_id: Optional[int] = Field(alias="getCompetitorAAId")


GetCompetitorAAId.update_forward_refs()
