# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetMetaData(BaseModel):
    get_meta_data: Optional["GetMetaDataGetMetaData"] = Field(alias="getMetaData")


class GetMetaDataGetMetaData(BaseModel):
    country_codes: Optional[
        List[Optional["GetMetaDataGetMetaDataCountryCodes"]]
    ] = Field(alias="countryCodes")
    discipline_codes: Optional[
        List[Optional["GetMetaDataGetMetaDataDisciplineCodes"]]
    ] = Field(alias="disciplineCodes")


class GetMetaDataGetMetaDataCountryCodes(BaseModel):
    code: Optional[str]
    name: Optional[str]


class GetMetaDataGetMetaDataDisciplineCodes(BaseModel):
    code: Optional[str]
    name: Optional[str]


GetMetaData.update_forward_refs()
GetMetaDataGetMetaData.update_forward_refs()
GetMetaDataGetMetaDataCountryCodes.update_forward_refs()
GetMetaDataGetMetaDataDisciplineCodes.update_forward_refs()
