# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetWawCompetitionEventsOrganizerDetails(BaseModel):
    get_waw_competition_events_organizer_details: Optional[
        List[
            Optional[
                "GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetails"
            ]
        ]
    ] = Field(alias="getWawCompetitionEventsOrganizerDetails")


class GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetails(
    BaseModel
):
    id: Optional[int]
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    organizer_details: Optional[
        List[
            Optional[
                "GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetailsOrganizerDetails"
            ]
        ]
    ] = Field(alias="organizerDetails")


class GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetailsOrganizerDetails(
    BaseModel
):
    name: Optional[str]
    value: Optional[str]


GetWawCompetitionEventsOrganizerDetails.update_forward_refs()
GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetails.update_forward_refs()
GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetailsOrganizerDetails.update_forward_refs()
