# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetAssetsTotal(BaseModel):
    get_assets_total: Optional["GetAssetsTotalGetAssetsTotal"] = Field(
        alias="getAssetsTotal"
    )


class GetAssetsTotalGetAssetsTotal(BaseModel):
    total: Optional[str]


GetAssetsTotal.update_forward_refs()
GetAssetsTotalGetAssetsTotal.update_forward_refs()
